This repository contains EXPERIMENTAL code for interfacing with
Decimator Designs products. BUYER BEWARE! It has only received cursory
testing on the MD-HX converter. It's entirely possible for your device
to be BRICKED.

To install, use the standard pip tools (e.g. `pip install .`) and run
the "decimctl" command.